.. expect: role missing colon before first backtick

.. It also looks like:
.. expect: missing space before default role
.. even it's not.


Default: value of the ``PLATLIBDIR`` macro which is set by the
:option`configure --with-platlibdir option <--with-platlibdir>` (default:
``"lib"``).
